@@ -16,8 +16,6 @@ class CdswEnvVar(Enum):
     MAIL_ACC_PASSWORD = "MAIL_ACC_PASSWORD"
     MAIL_ACC_USER = "MAIL_ACC_USER"
     MAIL_RECIPIENTS = "MAIL_RECIPIENTS"
-    JENKINS_USER = "JENKINS_USER"
-    JENKINS_PASSWORD = "JENKINS_PASSWORD"
     CLOUDERA_HADOOP_ROOT = YarnDevToolsEnvVar.ENV_CLOUDERA_HADOOP_ROOT.value
     HADOOP_DEV_DIR = YarnDevToolsEnvVar.ENV_HADOOP_DEV_DIR.value
     PYTHONPATH = "PYTHONPATH"
@@ -61,7 +59,7 @@ class ReviewSyncEnvVar(Enum):
     BRANCHES = "BRANCHES"
 
 
-class UnitTestResultAggregatorEnvVar(Enum):
+class UnitTestResultAggregatorEmailEnvVar(Enum):
     GSHEET_CLIENT_SECRET = "GSHEET_CLIENT_SECRET"
     GSHEET_SPREADSHEET = "GSHEET_SPREADSHEET"
     GSHEET_WORKSHEET = "GSHEET_WORKSHEET"
