@@ -453,10 +453,12 @@ class SimpleRenderedSummary(RenderedSummaryAbs):
             ],
             eval_method=EvaluationMethod.ALL,
         )
-        self._add_all_comits_table(header, all_commits, colorize_conf=color_conf)
-        self._add_all_comits_table(header, all_commits, colorize_conf=None)
+        self._add_all_comits_table(header, all_commits, colorize_conf=color_conf, row_number_in_header=True)
+        self._add_all_comits_table(header, all_commits, colorize_conf=None, row_number_in_header=True)
 
-    def _add_all_comits_table(self, header, all_commits, colorize_conf: ColorizeConfig = None):
+    def _add_all_comits_table(
+        self, header, all_commits, colorize_conf: ColorizeConfig = None, row_number_in_header: bool = False
+    ):
         table_type = BranchComparatorTableType.ALL_COMMITS_MERGED
         colorize = True if colorize_conf else False
 
@@ -465,11 +467,27 @@ class SimpleRenderedSummary(RenderedSummaryAbs):
             print_result=False,
             max_width=100,
             max_width_separator=" ",
-            add_row_numbers=False,
+            add_row_numbers=True,
             tabulate_formats=DEFAULT_TABLE_FORMATS,
             bool_conversion_config=BoolConversionConfig(),
             colorize_config=colorize_conf,
         )
+
+        first_row = all_commits[0]
+        actual_columns = len(first_row)
+        expected_columns = len(header)
+        if row_number_in_header:
+            expected_columns = expected_columns - 1
+
+        if expected_columns != actual_columns:
+            raise ValueError(
+                "Header is misaligned! \n"
+                "Expected columns: {}, "
+                "Actual columns: {} \n"
+                "Row number in header: {} \n"
+                "Header: {} \n"
+                "First row: {}".format(expected_columns, actual_columns, row_number_in_header, header, first_row)
+            )
         gen_tables = ResultPrinter.print_tables(data=all_commits, header=header, render_conf=render_conf)
         for table_fmt, table in gen_tables.items():
             self.add_table(
