@@ -2,8 +2,7 @@ import datetime
 
 from marshmallow import fields, Schema
 
-from yarndevtools.common.common_model import AggregatorEntity
-from yarndevtools.common.db import DBSerializable
+from yarndevtools.common.common_model import AggregatorEntity, DBSerializable
 import logging
 
 MONGO_COLLECTION_EMAIL_CONTENT = "email_data"
@@ -22,6 +21,7 @@ class EmailContentSchema(Schema):
 
 
 class EmailContent(DBSerializable, AggregatorEntity):
+    # TODO should eliminate this class and use JobBuildData instead, msg_id, thread_id, date, subject should be added to Source object as a field
     def __init__(self, msg_id, thread_id, date, subject, build_url, job_name, build_number, lines):
         self.msg_id = msg_id
         self.thread_id = thread_id
