@@ -17,15 +17,21 @@ from pythoncommons.result_printer import (
 )
 from pythoncommons.string_utils import StringUtils, auto_str
 
-from yarndevtools.commands.unittestresultaggregator.common import (
-    get_key_by_testcase_filter,
+from yarndevtools.commands.unittestresultaggregator.constants import (
     OperationMode,
     SummaryMode,
-    TestCaseFilter,
-    FailedTestCase,
-    FailedTestCaseAggregated,
-    BuildComparisonResult,
 )
+from yarndevtools.commands.unittestresultaggregator.common.model import (
+    BuildComparisonResult,
+    FailedTestCaseAggregated,
+    TestCaseFilter,
+    FailedTestCaseAbs,
+    TestCaseFilters,
+    AggregatedFailurePropertyFilter,
+    FailedBuildFromEmail,
+)
+from yarndevtools.commands.unittestresultaggregator.common.aggregation import AggregationResults
+from yarndevtools.commands.unittestresultaggregator.db.model import EmailContent
 from yarndevtools.constants import (
     ReportFile,
 )
@@ -61,16 +67,16 @@ class TableDataType(Enum):
 class OutputFormatRules:
     truncate_length: bool
     abbrev_tc_package: str or None
-    truncate_subject_with: str or None
+    truncate_origin_with: str or None
 
 
-# TODO Get rid of this later?
 @auto_str
 class UnitTestResultAggregatorTableRenderingConfig(TableRenderingConfig):
+    # TODO refactor: Get rid of this class later?
     def __init__(
         self,
         data_type: TableDataType = None,
-        testcase_filters: List[TestCaseFilter] or None = None,
+        testcase_filters: TestCaseFilters or None = None,
         header: List[str] = None,
         table_types: List[TableOutputFormat] = None,
         out_fmt: OutputFormatRules or None = None,
@@ -87,12 +93,13 @@ class UnitTestResultAggregatorTableRenderingConfig(TableRenderingConfig):
         self.add_row_numbers = add_row_numbers
         self.max_width_separator = max_width_separator
         self.max_width = max_width
-        self.testcase_filters = [] if not testcase_filters else testcase_filters
+        self.testcase_filters = TestCaseFilters.create_empty() if not testcase_filters else testcase_filters
         self.header = header
         self.data_type = data_type
         self.table_types = table_types
         self.out_fmt = out_fmt
         self.simple_mode = simple_mode
+        # TODO refactor: Debug when these can be None: self.data_type, self.testcase_filters
         LOG.info(
             f"Testcase filters for data type '{self.data_type}': {[tcf.short_str() for tcf in self.testcase_filters]}"
         )
@@ -118,8 +125,8 @@ class SummaryGenerator:
         }
 
     @classmethod
-    def process_testcase_filter_results(
-        cls, tc_filter_results, query_result: ThreadQueryResults, config, output_manager
+    def process_aggregation_results(
+        cls, aggr_results: AggregationResults, query_result: ThreadQueryResults, config, output_manager
     ):
         if config.summary_mode != SummaryMode.NONE.value:
             # TODO fix
@@ -129,23 +136,23 @@ class SummaryGenerator:
             # We apply the specified truncation / abbreviation rules only for TEXT based tables
             # HTML / Gsheet output is just fine with longer names.
             # If SummaryMode.ALL is used, we leave all values intact for simplicity.
-            if config.abbrev_tc_package or config.truncate_subject_with:
+            if config.abbrev_tc_package or config.truncate_origin_with:
                 if config.summary_mode in [SummaryMode.ALL.value, SummaryMode.HTML.value]:
                     LOG.warning(
-                        f"Either abbreviate package or truncate subject is enabled "
+                        f"Either abbreviate package or truncate origin is enabled "
                         f"but SummaryMode is set to '{config.summary_mode}'. "
                         "Leaving all data intact so truncate / abbreviate options are ignored."
                     )
                     config.abbrev_tc_package = None
-                    config.truncate_subject_with = None
+                    config.truncate_origin_with = None
 
             data_dict: Dict[TableDataType, Callable[[TestCaseFilter, OutputFormatRules], List[List[str]]]] = {
                 TableDataType.MATCHED_LINES: lambda tcf, out_fmt: DataConverter.convert_data_to_rows(
-                    tc_filter_results.get_failed_testcases_by_filter(tcf),
+                    aggr_results.get_failures(tcf),
                     out_fmt,
                 ),
                 TableDataType.MATCHED_LINES_AGGREGATED: lambda tcf, out_fmt: DataConverter.render_aggregated_rows_table(
-                    tc_filter_results.get_aggregated_testcases_by_filter(tcf),
+                    aggr_results.get_aggregated_testcases_by_filters(tcf),
                     out_fmt,
                 ),
                 TableDataType.MAIL_SUBJECTS: lambda tcf, out_fmt: DataConverter.convert_email_subjects(query_result),
@@ -153,23 +160,23 @@ class SummaryGenerator:
                     query_result
                 ),
                 TableDataType.LATEST_FAILURES: lambda tcf, out_fmt: DataConverter.render_latest_failures_table(
-                    tc_filter_results.get_latest_failed_testcases_by_filter(tcf)
+                    aggr_results.get_latest_failures(tcf)
                 ),
                 TableDataType.BUILD_COMPARISON: lambda tcf, out_fmt: DataConverter.render_build_comparison_table(
-                    tc_filter_results.get_build_comparison_result_by_filter(tcf)
+                    aggr_results.get_build_comparison(tcf)
                 ),
                 TableDataType.UNKNOWN_FAILURES: lambda tcf, out_fmt: DataConverter.render_aggregated_rows_table(
-                    tc_filter_results.get_aggregated_testcases_by_filter(tcf, filter_unknown=True),
+                    aggr_results.get_aggregated_testcases_by_filters(tcf, AggregatedFailurePropertyFilter.UNKNOWN),
                     out_fmt,
                     basic_mode=True,
                 ),
                 TableDataType.REOCCURRED_FAILURES: lambda tcf, out_fmt: DataConverter.render_aggregated_rows_table(
-                    tc_filter_results.get_aggregated_testcases_by_filter(tcf, filter_reoccurred=True),
+                    aggr_results.get_aggregated_testcases_by_filters(tcf, AggregatedFailurePropertyFilter.REOCCURRED),
                     out_fmt,
                     basic_mode=True,
                 ),
                 TableDataType.TESTCASES_TO_JIRAS: lambda tcf, out_fmt: DataConverter.render_aggregated_rows_table(
-                    tc_filter_results.get_aggregated_testcases_by_filter(tcf), out_fmt
+                    aggr_results.get_aggregated_testcases_by_filters(tcf), out_fmt
                 ),
             }
 
@@ -197,14 +204,14 @@ class SummaryGenerator:
         if config.operation_mode == OperationMode.GSHEET:
             # We need to re-generate all the data here, as table renderer might rendered truncated data.
             LOG.info("Updating Google sheet with data...")
-            for tcf in config.testcase_filters.get_non_aggregate_filters():
-                failed_testcases = tc_filter_results.get_failed_testcases_by_filter(tcf)
+            for tcf in config.testcase_filter_defs.get_non_aggregate_filters():
+                failed_testcases = aggr_results.get_failures(tcf)
                 table_data = DataConverter.convert_data_to_rows(failed_testcases, OutputFormatRules(False, None, None))
                 SummaryGenerator._write_to_sheet(
                     config, "data", cls.matched_testcases_all_header, output_manager, table_data, tcf
                 )
-            for tcf in config.testcase_filters.get_aggregate_filters():
-                failed_testcases = tc_filter_results.get_aggregated_testcases_by_filter(tcf)
+            for tcf in config.testcase_filter_defs.get_aggregate_filters():
+                failed_testcases = aggr_results.get_aggregated_testcases_by_filters(tcf)
                 table_data = DataConverter.render_aggregated_rows_table(
                     failed_testcases, OutputFormatRules(False, None, None)
                 )
@@ -242,27 +249,27 @@ class SummaryGenerator:
             UnitTestResultAggregatorTableRenderingConfig(
                 data_type=TableDataType.BUILD_COMPARISON,
                 header=["Testcase", "Still failing", "Fixed", "New failure"],
-                testcase_filters=config.testcase_filters.LATEST_FAILURE_FILTERS,
+                testcase_filters=config.testcase_filter_defs.LATEST_FAILURE_FILTERS,
                 table_types=[TableOutputFormat.REGULAR, TableOutputFormat.HTML],
-                out_fmt=OutputFormatRules(truncate, config.abbrev_tc_package, config.truncate_subject_with),
+                out_fmt=OutputFormatRules(truncate, config.abbrev_tc_package, config.truncate_origin_with),
             ),
             UnitTestResultAggregatorTableRenderingConfig(
                 data_type=TableDataType.UNKNOWN_FAILURES,
-                testcase_filters=config.testcase_filters.get_match_expression_aggregate_filters(),
+                testcase_filters=config.testcase_filter_defs.get_match_expression_aggregate_filters(),
                 header=cls.matched_testcases_aggregated_header_basic,
                 table_types=[TableOutputFormat.REGULAR, TableOutputFormat.HTML],
                 out_fmt=OutputFormatRules(False, config.abbrev_tc_package, None),
             ),
             UnitTestResultAggregatorTableRenderingConfig(
                 data_type=TableDataType.REOCCURRED_FAILURES,
-                testcase_filters=config.testcase_filters.get_match_expression_aggregate_filters(),
+                testcase_filters=config.testcase_filter_defs.get_match_expression_aggregate_filters(),
                 header=cls.matched_testcases_aggregated_header_basic,
                 table_types=[TableOutputFormat.REGULAR, TableOutputFormat.HTML],
                 out_fmt=OutputFormatRules(False, config.abbrev_tc_package, None),
             ),
             UnitTestResultAggregatorTableRenderingConfig(
                 data_type=TableDataType.TESTCASES_TO_JIRAS,
-                testcase_filters=config.testcase_filters.get_match_expression_aggregate_filters(),
+                testcase_filters=config.testcase_filter_defs.get_match_expression_aggregate_filters(),
                 header=cls.matched_testcases_aggregated_header_full,
                 table_types=[TableOutputFormat.REGULAR, TableOutputFormat.HTML],
                 out_fmt=OutputFormatRules(False, config.abbrev_tc_package, None),
@@ -291,16 +298,16 @@ class SummaryGenerator:
             # --> 3 tables in case of 2 match expressions
             UnitTestResultAggregatorTableRenderingConfig(
                 data_type=TableDataType.MATCHED_LINES,
-                testcase_filters=config.testcase_filters.get_non_aggregate_filters(),
+                testcase_filters=config.testcase_filter_defs.get_non_aggregate_filters(),
                 header=cls.matched_testcases_all_header,
                 table_types=[TableOutputFormat.REGULAR, TableOutputFormat.HTML],
-                out_fmt=OutputFormatRules(truncate, config.abbrev_tc_package, config.truncate_subject_with),
+                out_fmt=OutputFormatRules(truncate, config.abbrev_tc_package, config.truncate_origin_with),
             ),
             # Render tables for all match expressions AND all aggregation filters
             # --> 4 tables in case of 2 match expressions and 2 aggregate filters
             UnitTestResultAggregatorTableRenderingConfig(
                 data_type=TableDataType.MATCHED_LINES_AGGREGATED,
-                testcase_filters=config.testcase_filters.get_aggregate_filters(),
+                testcase_filters=config.testcase_filter_defs.get_aggregate_filters(),
                 header=cls.matched_testcases_aggregated_header_full,
                 table_types=[TableOutputFormat.REGULAR, TableOutputFormat.HTML],
                 out_fmt=OutputFormatRules(False, config.abbrev_tc_package, None),
@@ -324,9 +331,9 @@ class SummaryGenerator:
             UnitTestResultAggregatorTableRenderingConfig(
                 data_type=TableDataType.LATEST_FAILURES,
                 header=["Testcase", "Failure date", "Subject"],
-                testcase_filters=config.testcase_filters.LATEST_FAILURE_FILTERS,
+                testcase_filters=config.testcase_filter_defs.LATEST_FAILURE_FILTERS,
                 table_types=[TableOutputFormat.REGULAR, TableOutputFormat.HTML],
-                out_fmt=OutputFormatRules(truncate, config.abbrev_tc_package, config.truncate_subject_with),
+                out_fmt=OutputFormatRules(truncate, config.abbrev_tc_package, config.truncate_origin_with),
             ),
         ] + SummaryGenerator.short_render_confs(config, truncate)
 
@@ -377,7 +384,7 @@ class SummaryGenerator:
         tables: List[GenericTableWithHeader] = []
         for conf in render_confs:
             for tcf in conf.testcase_filters:
-                alias = get_key_by_testcase_filter(tcf)
+                alias = tcf.key()
                 rendered_table = self._callback_dict[table_output_format](conf.data_type, alias=alias)
                 tables.append(rendered_table)
             if conf.simple_mode:
@@ -414,7 +421,7 @@ class SummaryGenerator:
         )
 
 
-# TODO Try to extract this to common class (pythoncommons?), BranchComparator should move to this implementation later.
+# TODO refactor: Try to extract this to common class (pythoncommons?), BranchComparator should move to this implementation later.
 class TableRenderer:
     def __init__(self):
         self._tables: Dict[str, List[GenericTableWithHeader]] = {}
@@ -432,7 +439,7 @@ class TableRenderer:
                 formats=conf.tabulate_formats,
             )
         for tcf in conf.testcase_filters:
-            key = get_key_by_testcase_filter(tcf)
+            key = tcf.key()
             self._render_tables(
                 header=conf.header,
                 data=data_callable(tcf, conf.out_fmt),
@@ -591,50 +598,58 @@ class UnitTestResultOutputManager:
         )
 
 
-# TODO This should be a simple renderer class without any data business logic
+# TODO refactor: This should be a simple renderer class without any data business logic
 class DataConverter:
-    SUBJECT_MAX_LENGTH = 50
+    ORIGIN_MAX_LENGTH = 50
     LINE_MAX_LENGTH = 80
 
     @staticmethod
-    def convert_data_to_rows(failed_testcases: List[FailedTestCase], out_fmt: OutputFormatRules) -> List[List[str]]:
+    def convert_data_to_rows(failed_testcases: List[FailedTestCaseAbs], out_fmt: OutputFormatRules) -> List[List[str]]:
         data_table: List[List[str]] = []
-        truncate_subject_by_length: bool = out_fmt.truncate_length
+        truncate_origin_by_length: bool = out_fmt.truncate_length
         truncate_testcase_by_length: bool = out_fmt.truncate_length
 
         for testcase in failed_testcases:
-            subject, testcase_name = DataConverter._apply_truncate_rules(
-                out_fmt, testcase, truncate_subject_by_length, truncate_testcase_by_length
+            origin, testcase_name = DataConverter._apply_truncate_rules(
+                out_fmt, testcase, truncate_origin_by_length, truncate_testcase_by_length
             )
+
+            # TODO yarndevtoolsv2 DB: dirty hack to get email fields
+            message_id, thread_id = "", ""
+            failed_build: FailedBuildFromEmail = getattr(testcase, "_failed_build")
+            if isinstance(failed_build, FailedBuildFromEmail):
+                email_content: EmailContent = getattr(failed_build, "_email_content")
+                message_id, thread_id = email_content.msg_id, email_content.thread_id
+
             data_table.append(
                 [
-                    str(testcase.email_meta.date),
-                    subject,
+                    str(testcase.date()),
+                    origin,
                     testcase_name,
-                    testcase.email_meta.message_id,
-                    testcase.email_meta.thread_id,
+                    message_id,
+                    thread_id,
                 ]
             )
         return data_table
 
     @staticmethod
-    def _apply_truncate_rules(out_fmt, testcase, truncate_subject_by_length, truncate_testcase_by_length):
+    def _apply_truncate_rules(out_fmt, testcase, truncate_origin_by_length, truncate_testcase_by_length):
         # Don't touch the original MatchObject data.
-        # It's not memory efficient to copy subject / TC name but we need the
+        # It's not memory efficient to copy origin / TC name but we need the
         # untruncated / original fields later.
-        subject = copy.copy(testcase.email_meta.subject)
-        testcase_name = copy.copy(testcase.full_name)
-        if out_fmt.truncate_subject_with:
-            subject = DataConverter._truncate_subject(subject, out_fmt.truncate_subject_with)
+        origin = copy.copy(testcase.origin())
+        testcase_name = copy.copy(testcase.full_name())
+        if out_fmt.truncate_origin_with:
+            origin = DataConverter._truncate_origin(origin, out_fmt.truncate_origin_with)
         if out_fmt.abbrev_tc_package:
             testcase_name = DataConverter._abbreviate_package_name(out_fmt.abbrev_tc_package, testcase_name)
 
         # Check length-based truncate, if still necessary
-        if truncate_subject_by_length and len(subject) > DataConverter.SUBJECT_MAX_LENGTH:
-            subject = DataConverter._truncate_str(subject, DataConverter.SUBJECT_MAX_LENGTH, "subject")
+        if truncate_origin_by_length and len(origin) > DataConverter.ORIGIN_MAX_LENGTH:
+            origin = DataConverter._truncate_str(origin, DataConverter.ORIGIN_MAX_LENGTH, "origin")
         if truncate_testcase_by_length:
             testcase_name = DataConverter._truncate_str(testcase_name, DataConverter.LINE_MAX_LENGTH, "testcase")
-        return subject, testcase_name
+        return origin, testcase_name
 
     @staticmethod
     def _abbreviate_package_name(abbrev_tc_package, testcase_name):
@@ -646,12 +661,12 @@ class DataConverter:
         return testcase_name
 
     @staticmethod
-    def _truncate_subject(subject, truncate_subject_with):
-        if truncate_subject_with in subject:
-            new_subject = "".join([s for s in subject.split(truncate_subject_with) if s])
-            LOG.debug(f"Truncated subject: '{subject}' -> {new_subject}")
-            subject = new_subject
-        return subject
+    def _truncate_origin(origin, truncate_origin_with):
+        if truncate_origin_with in origin:
+            new_origin = "".join([s for s in origin.split(truncate_origin_with) if s])
+            LOG.debug(f"Truncated origin: '{origin}' -> {new_origin}")
+            origin = new_origin
+        return origin
 
     @staticmethod
     def render_aggregated_rows_table(
@@ -674,21 +689,21 @@ class DataConverter:
         return [tc_name, tc_param, testcase.failure_freq, str(testcase.latest_failure)]
 
     @staticmethod
-    def render_latest_failures_table(failed_testcases: List[FailedTestCase]) -> List[List[str]]:
+    def render_latest_failures_table(failed_testcases: List[FailedTestCaseAbs]) -> List[List[str]]:
         data_table: List[List[str]] = []
         for testcase in failed_testcases:
-            data_table.append([testcase.full_name, testcase.email_meta.date, testcase.email_meta.subject])
+            data_table.append([testcase.full_name, testcase.date(), testcase.origin()])
         return data_table
 
     @classmethod
     def render_build_comparison_table(cls, result: BuildComparisonResult):
         data_table: List[List[str]] = []
         for tc in result.still_failing:
-            data_table.append([tc.full_name, True, False, False])
+            data_table.append([tc.full_name(), True, False, False])
         for tc in result.fixed:
-            data_table.append([tc.full_name, False, True, False])
-        for tc in result.new_failures:
-            data_table.append([tc.full_name, False, False, True])
+            data_table.append([tc.full_name(), False, True, False])
+        for tc in result.new:
+            data_table.append([tc.full_name(), False, False, True])
         return data_table
 
     @staticmethod
